@@ -62,7 +62,7 @@
 #define KPIPEWIREDMABUF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIREDMABUF_NO_DEPRECATED
-#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6035a
+#  define KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6035b
 #endif
 #ifdef KPIPEWIREDMABUF_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE KPIPEWIREDMABUF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x6035a
+#    define KPIPEWIREDMABUF_DEPRECATED_WARNINGS_SINCE 0x6035b
 #  endif
 #endif
 
